@@ -1,12 +1,9 @@
-context("TaskRegr")
-
-
 test_that("autoplot.TaskRegr", {
-  task = mlr_tasks$get("mtcars")$select(c("carb", "cyl"))
+  task = mlr3::tsk("mtcars")$select(c("carb", "cyl"))
 
   p = autoplot(task, type = "target")
   expect_true(is.ggplot(p))
 
   p = autoplot(task, type = "pairs")
-  expect_is(p, "ggmatrix")
+  expect_s3_class(p, "ggmatrix")
 })
